@@ -38,6 +38,7 @@ from . import (
     service,
     settings,
     sqlalchemy_plugin,
+    type_encoders,
     worker,
 )
 from .init_plugin import ConfigureApp, PluginConfig
@@ -61,7 +62,8 @@ __all__ = [
     "service",
     "settings",
     "sqlalchemy_plugin",
+    "type_encoders",
     "worker",
 ]
 
-__version__ = "0.28.0"
+__version__ = "0.28.1"
